@@ -64,18 +64,15 @@ def download(type, local_dir_path):
 @click.command(name="deploy")
 @click.option(
     '--type', 
-    default="aitemplate", 
+    default="auto", 
     show_default=True, 
     help='Model type', 
     type=click.Choice([
+        'auto',
+        'cloud',
         'pytorch', 
         'aitemplate', 
-        'tensorrt',
-        'nvfuser',
-        'flash_attention',
-        'onnx_cuda',
-        'auto',
-        'cloud'
+        'tensorrt'
     ], case_sensitive=False)
 )
 @click.option(
@@ -98,24 +95,39 @@ def deploy(type, port):
         StableDiffusionDeployments.deploy()
         
     else: # local
-        gpu2type = {"a100":"aitemplate",
-                    "t4":"tensorrt"}
+        gpu2type = {
+            "a100":"aitemplate",
+            "t4":"tensorrt"
+        }
         gpu_info = get_gpu_info()[0]
         
         # If there is no GPU
         if gpu_info is None or len(gpu_info) == 0:
             logger.warning("Please install gpu driver or use the machine which has gpu")
             return
+
+        # Support only for T4 and A100 GPUs
         if gpu_info["name"] not in gpu2type:
             logger.warning("Currently we only support a100 and t4 gpus. We may support other gpus in the future")
             return
+
+        click.secho(
+            "[+] GPU detected: {}".format(gpu_info.get("name")), 
+            fg="blue", 
+            bold=True
+        )
         
         # If there is GPU
         if type == "auto":
+            # aitemplate or tensorrt
             type = gpu2type[gpu_info["name"]]
             click.secho("[+] Your gpu is {}, the best option is {}".format(gpu_info["name"],type), fg='blue', bold=True)
+
         if type == "tensorrt":        
-            docker_image = "public.ecr.aws/t8g5g2q5/stable-diffusion:{}_{}".format(type,gpu_info["name"].lower())
+            docker_image = "public.ecr.aws/t8g5g2q5/stable-diffusion:{}_{}".format(
+                type, 
+                gpu_info["name"].lower()
+            )
         else:
             docker_image = "public.ecr.aws/t8g5g2q5/stable-diffusion:{}".format(type)
 
@@ -140,7 +152,7 @@ def deploy(type, port):
     '--id', 
     help='The ID of the deployment'
 )
-def list(id):
+def list_command(id):
     click.secho("\n[+] Deployments\n", fg='blue', bold=True)
     
     if id is not None:
@@ -179,12 +191,15 @@ def stop(cloud_id):
 @click.option(
     '--prompt', 
     required=True, 
-    help='Prompt to generate images', 
+    type=str,
+    help='Prompt to generate images'
 )
 @click.option(
     '--cloud_id', 
-    required=False, 
-    help='Cloud ID deployment', 
+    default=None,
+    type=str, 
+    show_default=True,
+    help='Cloud ID deployment'
 )
 @click.option(
     '--img_height', 
@@ -242,22 +257,25 @@ def infer(
     saving_path = Path(saving_path)
     if not saving_path.exists():
         saving_path.mkdir(exist_ok=True, parents=True)   
-            
+ 
     if cloud_id is not None:
         deployment = StableDiffusionDeployments.get_deployment(cloud_id)
         url = deployment.client_url
         headers = {
             "apiKey": deployment.api_key
         }
-    else:                        
+    else:                   
         ports = get_open_ports_container("stochasticx_stable_diffusion")
         if len(ports) == 0:
-            print("[+] Before doing the inference you have to run: stochasticx stable-diffusion deploy")
+            click.secho("[+] Before doing the inference you have to run: stochasticx stable-diffusion deploy", fg='yellow', bold=True)
             sys.exit()
             
-        url = "http://127.0.0.1:{}/predict".format(list(ports.values())[0])
+        url = "http://127.0.0.1:{}/predict".format(
+            list(ports.values())[0]
+        )
         headers = {}
         
+    
     click.secho("[+] Generating images...", fg='blue', bold=True)
     images, time = inference(
         url=url,
@@ -292,5 +310,5 @@ stable_diffusion.add_command(download)
 stable_diffusion.add_command(deploy)
 stable_diffusion.add_command(logs)
 stable_diffusion.add_command(stop)
-stable_diffusion.add_command(list)
+stable_diffusion.add_command(list_command)
 stable_diffusion.add_command(infer)
\ No newline at end of file
