@@ -11,6 +11,8 @@ from stochasticx.utils.auth_utils import AuthUtils
 from stochasticx.models.models import OptimizedModel, Models
 from stochasticx.utils.logging import configure_logger
 from stochasticx.utils.parse_utils import parse_date
+import click
+import sys
 
 logger = configure_logger(__name__)
 
@@ -471,16 +473,31 @@ class StableDiffusionDeployments:
         r.raise_for_status()
         
         data = r.json()
+        deploying = False
         
         if data["data"] is not None:
             for deployment_data in data["data"]:
+                
+                api_key = None
+                client_url = None
+                if deployment_data.get("resources") is not None:
+                    api_key = deployment_data.get("resources").get("apiKey")
+                    client_url = deployment_data.get("clientUrl")
+                else:
+                    deploying = True
+                
                 deployment = StableDiffusionDeployment(
                     id=deployment_data.get('id'),
                     status=deployment_data.get('status'),
-                    model_name=deployment_data.get('modelName')
+                    model_name=deployment_data.get('modelName'),
+                    client_url=client_url,
+                    api_key=api_key
                 )
                 deployments.append(deployment)
                 
+        if deploying:
+            click.secho("[+] There are models that are still deploying. It can take some minutes...\n", bold=True, fg="yellow")
+                
         return deployments
     
     @staticmethod
@@ -489,7 +506,12 @@ class StableDiffusionDeployments:
         
         auth_header = AuthUtils.get_auth_headers()
         r = requests.get(url, headers=auth_header)
-        r.raise_for_status()
+        
+        try:
+            r.raise_for_status()
+        except:
+            click.secho("[+] The ID is not correct\n", bold=True, fg="yellow")
+            sys.exit()
         
         data = r.json()
         deployment_data = data["deployedModel"]
@@ -512,6 +534,12 @@ class StableDiffusionDeployments:
                     model_name=deployment_data.get('modelName'),
                 )
                 
+                click.secho(
+                    "[+] The model is still deploying. It can take some minutes...", 
+                    bold=True, 
+                    color="yellow"
+                )
+                
             return deployment
             
         return None
