@@ -5,6 +5,7 @@ from pathlib import Path
 from stochasticx.constants.urls import LOGIN_URL, TOKEN_AUTH_PATH
 import sys
 import click
+from stochasticx.constants.urls import ME_URL
 
 
 class LoginUtils:
@@ -22,7 +23,15 @@ class LoginUtils:
         login_info = {"email": username, "password": password}
 
         response = requests.post(LOGIN_URL, data=login_info)
-        response.raise_for_status()
+        try:
+            response.raise_for_status()
+        except:
+            click.secho(
+                "[+] Your credentials are not correct.\n", 
+                fg='red', 
+                bold=True
+            )
+            sys.exit()
 
         response_data = response.json()
         token = response_data["token"]
@@ -63,15 +72,31 @@ class AuthUtils:
                 data = json.load(f)
                 token = data['token']
 
+        if token is not None:
+            try:
+                response = requests.get(
+                    ME_URL, 
+                    headers={
+                        'Authorization': 'Bearer ' + token
+                    }
+                )
+                response.raise_for_status()
+            except:
+                click.secho(
+                    "[+] You are not logged in\n", 
+                    fg='red', 
+                    bold=True
+                )
+                sys.exit()
         
-        if token is None:
+        else:
             click.secho(
-                "[+] Do login before running any request\n", 
+                "[+] You are not logged in\n", 
                 fg='red', 
                 bold=True
             )
             sys.exit()
-        else:
-            return {
-                'Authorization': 'Bearer ' + token
-            }
\ No newline at end of file
+
+        return {
+            'Authorization': 'Bearer ' + token
+        }    
\ No newline at end of file
